@@ -130,7 +130,9 @@ int alloc_peaks(int p_l, size_t iso_amount, double **m_, double **a_, int **cc_)
                 return R_NilValue;
             }
         }
-        SETLENGTH(trace_R, n + 1);
+
+		trace_R = Rf_lengthgets(trace_R, n + 1);		
+		
         UNPROTECT(4);
         return trace_R;
     }
@@ -302,8 +304,9 @@ int alloc_peaks(int p_l, size_t iso_amount, double **m_, double **a_, int **cc_)
                 UNPROTECT(1);
             }
 
-            SETLENGTH(mass_R, r);
-            SETLENGTH(a_R, r);
+			mass_R = Rf_lengthgets(mass_R, r);
+			a_R = Rf_lengthgets(a_R, r);
+			
             SET_VECTOR_ELT(iso_pattern, 0, mass_R);
             SET_VECTOR_ELT(iso_pattern, 1, a_R);
 
@@ -1724,8 +1727,8 @@ SEXP iso_pattern_2(SEXP sum
             UNPROTECT(1);
         }
 
-        SETLENGTH(mass_R, r);
-        SETLENGTH(a_R, r);
+		mass_R = Rf_lengthgets(mass_R, r);
+		a_R = Rf_lengthgets(a_R, r);
         SET_VECTOR_ELT(iso_pattern, 0, mass_R);
         SET_VECTOR_ELT(iso_pattern, 1, a_R);
 
